================================================================================
 `xoutil.eight`:mod: -- Extensions for writing code that runs on Python 2 and 3
================================================================================

.. module:: xoutil.eight

.. todo:: check automodule\ :\ : xoutil.eight
   \ :members\ :

The name comes from (Manu's idea') "2 raised to the power of 3".

This module is divided in several parts.

.. toctree::
   :glob:

   eight/abc
   eight/meta
   eight/mixins
   eight/string
   eight/text
   eight/io
   eight/queue
   eight/exceptions
